@@ -20,9 +20,9 @@ function tidepoolui_create_redis(?IniConfig $settings = null): Redis
 {
     $redis = new Redis();
     
-    $host = '127.0.0.1';
-    $port = 6379;
-    $db = 0;
+    $host = getenv('REDIS_HOST') ?: '127.0.0.1';
+    $port = (int)(getenv('REDIS_PORT') ?: 6379);
+    $db = (int)(getenv('REDIS_DB') ?: 0);
     
     if ($settings) {
         $host = $settings->getString('redis', 'host', $host);
